**To disassociate a principal from a portfolio**

The following ``disassociate-principal-from-portfolio`` example disassociates the specified principal from the portfolio. ::

    aws servicecatalog disassociate-principal-from-portfolio \
        --portfolio-id port-2s6abcdq5wdh4 \
        --principal-arn arn:aws:iam::123456789012:group/myendusers

This command produces no output.
